/**
 * @version $Id: template_rtl.css 9141 2007-10-04 08:23:14Z mtk $
 * @package Joomla
 * @subpackage Template-rhuk_milkway
 * @copyright Copyright (C) 2005 - 2008 Open Source Matters. All rights reserved.
 * @license GNU/GPL, see LICENSE.php
 * Joomla! is free software. This version may have been modified pursuant to the
 * GNU General Public License, and as distributed it includes or is derivative
 * of works licensed under the GNU General Public License or other free or open
 * source software licenses. See COPYRIGHT.php for copyright notices and
 * details.
 */
 
 /**
 * Joomla! 1.5 rhuk_milkway template RTL css file
 *
 * @author 		Mati Kochen
 * @package		Joomla
 * @since		1.5
 * @version     1.0
 */

body{
	direction: rtl;
}

div#logo {
	float:right;
	right:0pt;
	left:auto;
	margin-left:0px;
	margin-right:30px;
}

div#header_r {
	text-align:right;
	padding-right:370px;
	padding-left:30px;
}

td.pill_m {
    background: url(../images/mw_menu_normal_bg.png) repeat-x;
}

td.pill_r {
	background:transparent url(../images/mw_menu_cap_l.png) no-repeat scroll 0%;
}

td.pill_l {
	background:transparent url(../images/mw_menu_cap_r.png) no-repeat scroll 0%;
}

#pillmenu {
	float:none;
}

#pillmenu ul {
	width: 420px;
}

#pillmenu li{
	float: right;
}

#pillmenu a {
	float:none;
	padding: 0px 10px;
}

#search{
	float: left;
	margin-right: 0px;
	margin-left: 30px;
	text-align: left;
}

#mod_search_searchword {
	padding-right:3px;
}

#pathway{
	margin-left: 250px;
	margin-right: 0px;
	text-align: right;
}

#whitebox div {
	text-align:right;
}

#leftcolumn {
	float:right;
}

#maincolumn, #maincolumn_full {
	margin-right: 20%;
	margin-left: 0%;
	padding-right: 15px;
	padding-left: 0px;
}

h3, .componentheading, table.moduletable th, legend{
	text-align: right;
}

div.module_menu h3{
	padding-right: 10px;
	padding-left: 0px;
}

div.module_menu ul{
	padding-right: 20px;
	padding-left: 0px;
}

h1 {
	text-align: right;	
}
	
h2, .contentheading{
	text-align: right;
}

td.buttonheading {
	text-align:left;
}

.small, .modifydate{
	text-align: right;
}

.pollstableborder td {
	text-align:right;
}

.article_column {
	padding-right:0px;
	padding-left:5px;
}

.column_separator {
	border-right: 1px dashed #E0E0E0;
	border-left: none;
	padding-right: 10px;
	padding-left: 0px;
}

form#form-login ul {
	padding-right: 20px;
	padding-left: 0px;
}

form#com-form-login ul {
	padding-right: 20px;
	padding-left: 0px;
}

a.readon {
	background:transparent url(../images/mw_readon_rtl.png) no-repeat scroll left top;
	float:right;
	padding-right:0px;
	padding-left:20px;
}

#syndicate{
	float:right;
	padding-left: 0px;
	padding-right: 25px;
}

#power_by{
	float:left;
	padding-right: 0px;
	padding-left: 25px;
}

.contentpaneopen_edit {
	float:right;
}

table.contenttoc{
	float: left;
}

span.pagination a{
	float: right;
}

span.pagination span{
	float: right;
	display: block;
}
