/**
* @version $Id: popup-imagelist.css 3997 2006-06-12 03:59:51Z spacemonkey $
* @copyright Copyright (C) 2005 - 2008 Open Source Matters. All rights reserved.
* @license GNU/GPL, see LICENSE.php
* Joomla! is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/

/**
 * JImageManager imagelist styling
 *
 * @author		Johan Janssens <johan.janssens@joomla.org>
 * @package		Joomla
 * @since		1.5
 * @version    1.0
 */

 html, body { margin: 0; padding: 0; font: 10px Tahoma, Verdana, sans-serif; }

.item { float: left; border: 1px solid #ccc; margin: 3px; position: relative; }

.item a       {
	display: table-cell; _display: block;
	width: 80px; height: 80px;
	vertical-align:middle;  text-align: center;
	text-decoration: none;
	color: black;
}
.item a:hover { background-color: white;  }

.item img {  border: 0 none;  margin-top: expression(( 80 - this.height ) / 2);  }
.item span {
	display: block; width: 76px;
	position: absolute; bottom: 0; padding: 2px;
	background-color: #ddd;
	filter:alpha(opacity=70);
	-moz-opacity: 0.70;
	opacity: 0.70;
}

