/**
* @version $Id: menu_rtl.css 10387 2008-06-03 10:59:16Z pasamio $
* @copyright Copyright (C) 2005 - 2008 Open Source Matters. All rights reserved.
* @license GNU/GPL, see LICENSE.php
* Joomla! is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/

/**
 * JMenu javascript behavior styling
 *
 * @author		Mati Kochen
 * @package		Joomla
 * @since		1.5
 * @version    1.0
 */

/* ---- Basic menu styles ------------------- */

/* common styling */
#menu li {
	border-right:1px solid #FFFFFF;
	border-left:1px solid #D8D8D8;
	float: right;
}

#menu li.hover li.hover ul { left: auto; right: 100%; }

#menu a, #menu div{
	background-position: right;
	margin: 0 0 0 1px;
}

#menu ul{
	background-position:right;
}

#menu ul li.node {
	background:transparent url(../images/j_arrow_left.png) no-repeat scroll left 50%;
}

#menu li ul { left: auto; right: 0%}


#menu ul a {
	padding-right:25px;
	padding-left:20px;
}

#submenu li {
	float:right;
}

#submenu li a,
#submenu span.nolink {
	border-right:none;
	border-left:1px solid #CCCCCC;
	display: -moz-inline-box;
}